@@ -6,11 +6,11 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 1.05_04
+Version 1.11_01
 
 =cut
 
-our $VERSION = "1.05_04";
+our $VERSION = "1.11_01";
 
 =head1 SYNOPSIS
 
@@ -33,8 +33,8 @@ a history of the URLs you've visited, which can be queried and revisited.
     $mech->submit_form(
         form_number => 3,
         fields      => {
-            username    => 'yourname',
-            password    => 'dummy',
+            username    => 'mungo',
+            password    => 'lost-and-alone',
         }
     );
 
@@ -101,7 +101,7 @@ use HTML::Form 1.00;
 use HTML::TokeParser;
 use URI::URL;
 
-our @ISA = qw( LWP::UserAgent );
+use base 'LWP::UserAgent';
 
 =head1 CONSTRUCTOR AND STARTUP
 
@@ -324,7 +324,7 @@ sub get {
 
 =head2 $mech->reload()
 
-Acts like the reload button in a browser: Reperforms the current
+Acts like the reload button in a browser: repeats the current
 request. The history (as per the L<back> method) is not altered.
 
 Returns the L<HTTP::Response> object from the reload, or C<undef>
@@ -335,10 +335,9 @@ if there's no current request.
 sub reload {
     my $self = shift;
 
-    return unless $self->{req};
+    return unless my $req = $self->{req};
 
-    local $self->{inhibit_page_stack} = 1;
-    return $self->request( $self->{req});
+    $self->_update_page( $req, $self->_make_request( $req, @_ ) );
 }
 
 =head2 $mech->back()
@@ -597,7 +596,7 @@ key/value pairs:
 
 =over 4
 
-=item * C<< text => string >> and C<< text_regex => regex >>
+=item * C<< text => 'string', >> and C<< text_regex => qr/regex/, >>
 
 C<text> matches the text of the link against I<string>, which must be an
 exact match.  To select a link with text that is exactly "download", use
@@ -613,7 +612,7 @@ Note that the text extracted from the page's links are trimmed.  For
 example, C<< <a> foo </a> >> is stored as 'foo', and searching for
 leading or trailing spaces will fail.
 
-=item * C<< url => string >> and C<< url_regex => regex >>
+=item * C<< url => 'string', >> and C<< url_regex => qr/regex/, >>
 
 Matches the URL of the link against I<string> or I<regex>, as appropriate.
 The URL may be a relative URL, like F<foo/bar.html>, depending on how
@@ -679,40 +678,14 @@ sub find_link {
 
     my $wantall = ( $parms{n} eq "all" );
 
-    for my $key ( keys %parms ) {
-        my $val = $parms{$key};
-        if ( $key !~ /^(n|(text|url|url_abs|name|tag)(_regex)?)$/ ) {
-            $self->warn( qq{Unknown link-finding parameter "$key"} );
-            delete $parms{$key};
-            next;
-        }
-
-        if ( ($key =~ /_regex$/) && (ref($val) ne "Regexp" ) ) {
-            $self->warn( qq{$val passed as $key is not a regex} );
-            delete $parms{$key};
-            next;
-        }
-
-        if ($key !~ /_regex$/) {
-            if (ref($val) eq "Regexp") {
-                $self->warn( qq{$val passed as '$key' is a regex} );
-                delete $parms{$key};
-                next;
-            }
-            if ($val =~ /^\s|\s$/) {
-                $self->warn( qq{'$val' is space-padded and cannot succeed} );
-                delete $parms{$key};
-                next;
-            }
-        }
-    } # for keys %parms
+    $self->_clean_keys( \%parms, qr/^(n|(text|url|url_abs|name|tag)(_regex)?)$/ );
 
     my @links = $self->links or return;
 
     my $nmatches = 0;
     my @matches;
     for my $link ( @links ) {
-        if ( _match_any_parms($link,\%parms) ) {
+        if ( _match_any_link_parms($link,\%parms) ) {
             if ( $wantall ) {
                 push( @matches, $link );
             } else {
@@ -732,29 +705,67 @@ sub find_link {
 
 # Used by find_links to check for matches
 # The logic is such that ALL parm criteria that are given must match
-sub _match_any_parms {
+sub _match_any_link_parms {
     my $link = shift;
     my $p = shift;
 
     # No conditions, anything matches
     return 1 unless keys %$p;
 
-    return if defined $p->{url}          and !($link->url eq $p->{url} );
-    return if defined $p->{url_regex}    and !($link->url =~ $p->{url_regex} );
-    return if defined $p->{url_abs}      and !($link->url_abs eq $p->{url_abs} );
-    return if defined $p->{url_abs_regex}and !($link->url_abs =~ $p->{url_abs_regex} );
-    return if defined $p->{text}         and !(defined($link->text) and $link->text eq $p->{text} );
-    return if defined $p->{text_regex}   and !(defined($link->text) and $link->text =~ $p->{text_regex} );
-    return if defined $p->{name}         and !(defined($link->name) and $link->name eq $p->{name} );
-    return if defined $p->{name_regex}   and !(defined($link->name) and $link->name =~ $p->{name_regex} );
-    return if defined $p->{tag}          and !($link->tag and $link->tag eq $p->{tag} );
-    return if defined $p->{tag_regex}    and !($link->tag and $link->tag =~ $p->{tag_regex} );
+    return if defined $p->{url}           and !($link->url eq $p->{url} );
+    return if defined $p->{url_regex}     and !($link->url =~ $p->{url_regex} );
+    return if defined $p->{url_abs}       and !($link->url_abs eq $p->{url_abs} );
+    return if defined $p->{url_abs_regex} and !($link->url_abs =~ $p->{url_abs_regex} );
+    return if defined $p->{text}          and !(defined($link->text) and $link->text eq $p->{text} );
+    return if defined $p->{text_regex}    and !(defined($link->text) and $link->text =~ $p->{text_regex} );
+    return if defined $p->{name}          and !(defined($link->name) and $link->name eq $p->{name} );
+    return if defined $p->{name_regex}    and !(defined($link->name) and $link->name =~ $p->{name_regex} );
+    return if defined $p->{tag}           and !($link->tag and $link->tag eq $p->{tag} );
+    return if defined $p->{tag_regex}     and !($link->tag and $link->tag =~ $p->{tag_regex} );
 
     # Success: everything that was defined passed.
     return 1;
 
 }
 
+# Cleans the %parms parameter for the find_link and find_image methods.
+sub _clean_keys {
+    my $self = shift;
+    my $parms = shift;
+    my $rx_keyname = shift;
+
+    for my $key ( keys %$parms ) {
+        my $val = $parms->{$key};
+        if ( $key !~ qr/$rx_keyname/ ) {
+            $self->warn( qq{Unknown link-finding parameter "$key"} );
+            delete $parms->{$key};
+            next;
+        }
+
+        my $key_regex = ( $key =~ /_regex$/ );
+        my $val_regex = ( ref($val) eq "Regexp" );
+
+        if ( $key_regex ) {
+            if ( !$val_regex ) {
+                $self->warn( qq{$val passed as $key is not a regex} );
+                delete $parms->{$key};
+                next;
+            }
+        } else {
+            if ( $val_regex ) {
+                $self->warn( qq{$val passed as '$key' is a regex} );
+                delete $parms->{$key};
+                next;
+            }
+            if ( $val =~ /^\s|\s$/ ) {
+                $self->warn( qq{'$val' is space-padded and cannot succeed} );
+                delete $parms->{$key};
+                next;
+            }
+        }
+    } # for keys %parms
+} # _clean_keys()
+
 
 =head2 $mech->find_all_links( ... )
 
@@ -792,8 +803,134 @@ sub images {
     return $self->{images};
 }
 
+=head2 $mech->find_image()
+
+Finds an image in the current page. It returns a
+L<WWW::Mechanize::Image> object which describes the image.  If it fails
+to find an image it returns undef.
+
+You can select which link to find by passing in one or more of these
+key/value pairs:
+
+=over 4
+
+=item * C<< alt => 'string' >> and C<< alt_regex => qr/regex/, >>
+
+C<alt> matches the ALT attribute of the image against I<string>, which must be an
+exact match. To select a image with an ALT tag that is exactly "download", use
+
+    $mech->find_image( alt  => "download" );
+
+C<alt_regex> matches the ALT attribute of the image  against a regular
+expression.  To select an image with an ALT attribute that has "download"
+anywhere in it, regardless of case, use
+
+    $mech->find_image( alt_regex => qr/download/i );
+
+=item * C<< url => 'string', >> and C<< url_regex => qr/regex/, >>
+
+Matches the URL of the image against I<string> or I<regex>, as appropriate.
+The URL may be a relative URL, like F<foo/bar.html>, depending on how
+it's coded on the page.
+
+=item * C<< url_abs => string >> and C<< url_abs_regex => regex >>
+
+Matches the absolute URL of the image against I<string> or I<regex>,
+as appropriate.  The URL will be an absolute URL, even if it's relative
+in the page.
+
+=item * C<< tag => string >> and C<< tag_regex => regex >>
+
+Matches the tag that the image came from against I<string> or I<regex>,
+as appropriate.  The C<tag_regex> is probably most useful to check for
+more than one tag, as in:
+
+    $mech->find_image( tag_regex => qr/^(img|input)$/ );
+
+The tags supported are C<< <img> >> and C<< <input> >>.
+
+=back
+
+If C<n> is not specified, it defaults to 1.  Therefore, if you don't
+specify any parms, this method defaults to finding the first image on the
+page.
+
+Note that you can specify multiple ALT or URL parameters, which
+will be ANDed together.  For example, to find the first image with
+ALT text of "News" and with "cnn.com" in the URL, use:
+
+    $mech->find_image( image => "News", url_regex => qr/cnn\.com/ );
+
+The return value is a reference to an array containing a
+L<WWW::Mechanize::Image> object for every image in C<< $self->content >>.
+
+=cut
+
+sub find_image {
+    my $self = shift;
+    my %parms = ( n=>1, @_ );
+
+    my $wantall = ( $parms{n} eq "all" );
+
+    $self->_clean_keys( \%parms, qr/^(n|(alt|url|url_abs|tag)(_regex)?)$/ );
+
+    my @images = $self->images or return;
+
+    my $nmatches = 0;
+    my @matches;
+    for my $image ( @images ) {
+        if ( _match_any_image_parms($image,\%parms) ) {
+            if ( $wantall ) {
+                push( @matches, $image );
+            } else {
+                ++$nmatches;
+                return $image if $nmatches >= $parms{n};
+            }
+        }
+    } # for @images
+
+    if ( $wantall ) {
+        return @matches if wantarray;
+        return \@matches;
+    }
+
+    return;
+}
+
+# Used by find_images to check for matches
+# The logic is such that ALL parm criteria that are given must match
+sub _match_any_image_parms {
+    my $image = shift;
+    my $p = shift;
+
+    # No conditions, anything matches
+    return 1 unless keys %$p;
+
+    return if defined $p->{url}           and !($image->url eq $p->{url} );
+    return if defined $p->{url_regex}     and !($image->url =~ $p->{url_regex} );
+    return if defined $p->{url_abs}       and !($image->url_abs eq $p->{url_abs} );
+    return if defined $p->{url_abs_regex} and !($image->url_abs =~ $p->{url_abs_regex} );
+    return if defined $p->{alt}           and !(defined($image->alt) and $image->alt eq $p->{alt} );
+    return if defined $p->{alt_regex}     and !(defined($image->alt) and $image->alt =~ $p->{alt_regex} );
+    return if defined $p->{tag}           and !($image->tag and $image->tag eq $p->{tag} );
+    return if defined $p->{tag_regex}     and !($image->tag and $image->tag =~ $p->{tag_regex} );
+
+    # Success: everything that was defined passed.
+    return 1;
+}
+
+
 =head2 $mech->find_all_images( ... )
 
+Returns all the images on the current page that match the criteria.  The
+method for specifying image criteria is the same as in C<L<find_image()>>.
+Each of the images returned is a L<WWW::Mechanize::Image> object.
+
+In list context, C<find_all_images()> returns a list of the images.
+Otherwise, it returns a reference to the list of images.
+
+C<find_all_images()> with no parameters returns all images in the page.
+
 =cut
 
 sub find_all_images {
@@ -920,10 +1057,12 @@ sub select {
 
     my $input = $form->find_input($name);
     if (!$input) {
-        $self->warn( qq{ Input "$name" not found } );
+        $self->warn( qq{Input "$name" not found} );
         return;
-    } elsif ($input->type ne 'option') {
-        $self->warn( qq{ Input "$name" is not type "select" } );
+    }
+
+    if ($input->type ne 'option') {
+        $self->warn( qq{Input "$name" is not type "select"} );
         return;
     }
 
@@ -974,10 +1113,10 @@ sub select {
     if (ref($value) eq "ARRAY") {
         $form->param($name, $value);
         return 1;
-    } else {
-        $form->value($name => $value);
-        return 1;
     }
+
+    $form->value($name => $value);
+    return 1;
 }
 
 =head2 $mech->set_fields( $name => $value ... )
@@ -1002,7 +1141,7 @@ sub set_fields {
     my $self = shift;
     my %fields = @_;
 
-    my $form = $self->current_form;
+    my $form = $self->current_form or $self->die( "No form defined" );
 
     while ( my ( $field, $value ) = each %fields ) {
         if ( ref $value eq 'ARRAY' ) {
@@ -1454,7 +1593,7 @@ sub save_content {
     close $fh;
 }
 
-=head1 OVERRIDDEN L<LWP::UserAgent> METHODS
+=head1 OVERRIDDEN LWP::UserAgent METHODS
 
 =head2 $mech->redirect_ok()
 
@@ -1500,35 +1639,8 @@ sub request {
         $self->_push_page_stack();
     }
 
-    $self->{req} = $request;
-    $self->{redirected_uri} = $request->uri->as_string;
-
-    my $res = $self->{res} = $self->_make_request( $request, @_ );
-
-    # These internal hash elements should be dropped in favor of
-    # the accessors soon. -- 1/19/03
-    $self->{status}  = $res->code;
-    $self->{base}    = $res->base;
-    $self->{ct}      = $res->content_type || "";
-
-    if ( $res->is_success ) {
-        $self->{uri} = $self->{redirected_uri};
-        $self->{last_uri} = $self->{uri};
-    } else {
-        if ( $self->{autocheck} ) {
-            $self->die( "Error ", $request->method, "ing ", $request->uri, ": ", $res->message );
-        }
-    }
-
-    $self->_reset_page;
-    if ( $self->is_html ) {
-        $self->update_html( $res->content );
-    } else {
-        $self->{content} = $res->content;
-    }
-
-    return $res;
-} # request
+    $self->_update_page($request, $self->_make_request( $request, @_ ));
+}
 
 =head2 $mech->update_html( $html )
 
@@ -1539,7 +1651,7 @@ Say you have a page that you know has malformed output, and you want to
 update it so the links come out correctly:
 
     my $html = $mech->content;
-    $html =~ s[</option>.?.?.?</td>][</option></select></td>]isg;
+    $html =~ s[</option>.{0,3}</td>][</option></select></td>]isg;
     $mech->update_html( $html );
 
 This method is also used internally by the mech itself to update its
@@ -1552,7 +1664,7 @@ would overload I<update_html> in a subclass thusly:
 
    sub update_html {
        my ($self, $html) = @_;
-       $html =~ s[</option>.?.?.?</td>][</option></select></td>]isg;
+       $html =~ s[</option>.{0,3}</td>][</option></select></td>]isg;
        $self->WWW::Mechanize::update_html( $html );
    }
 
@@ -1575,68 +1687,19 @@ sub update_html {
     $self->{ct} = 'text/html';
     $self->{content} = $html;
 
-   $self->{forms} = [ HTML::Form->parse($html, $self->base) ];
-    if (@{ $self->{forms} }) {
-        for my $form (@{ $self->{forms} }) {
-            for my $input ($form->inputs) {
-                 if ($input->type eq 'file') {
-                     $input->value( undef );
-                 }
-            }
-       }
-    }
-    $self->{form}  = $self->{forms}->[0];
-    $self->_extract_links_and_images();
-
-    $self->_parse_html(); #For compatibility with folks that used to overload that method.
-
-    return;
-}
-
-=head2 $mech->_modify_request( $req )
-
-Modifies the request according to all the internal header mangling.
-
-=cut
-
-sub _modify_request {
-    my $self = shift;
-    my $req = shift;
-
-    # add correct Accept-Encoding header to restore compliance with
-    # http://www.freesoft.org/CIE/RFC/2068/158.htm
-    unless ( $req->header( 'Accept-Encoding' ) ) {
-        # Only allow "identity" for the time being
-        $req->header( 'Accept-Encoding', 'identity' );
-    }
-
-    my $last = $self->{last_uri};
-    if ( $last ) {
-        $last = $last->as_string if ref($last);
-        $req->header( Referer => $last );
-    }
-    while ( my($key,$value) = each %{$self->{headers}} ) {
-        if ( defined $value ) {
-            $req->header( $key => $value );
-        } else {
-            $req->remove_header( $key );
+    $self->{forms} = [ HTML::Form->parse($html, $self->base) ];
+    for my $form (@{ $self->{forms} }) {
+        for my $input ($form->inputs) {
+             if ($input->type eq 'file') {
+                 $input->value( undef );
+             }
         }
     }
+    $self->{form}  = $self->{forms}->[0];
+    $self->_extract_links();
+    $self->_extract_images();
 
-    return $req;
-}
-
-
-=head2 $mech->_make_request()
-
-Convenience method to make it easier for subclasses like
-L<WWW::Mechanize::Cached> to intercept the request.
-
-=cut
-
-sub _make_request {
-    my $self = shift;
-    $self->SUPER::request(@_);
+    return;
 }
 
 =head1 DEPRECATED METHODS
@@ -1706,22 +1769,99 @@ sub form {
     return $arg =~ /^\d+$/ ? $self->form_number($arg) : $self->form_name($arg);
 }
 
-=head2 $mech->_parse_html()
-
-An internal method that initializes forms and links given a HTML
-document.  Overriding this in your subclass is B<DEPRECATED>, better
-override L</update_html> instead in your new code.
-
-=cut
-
-sub _parse_html { }
-
-
 =head1 INTERNAL-ONLY METHODS
 
 These methods are only used internally.  You probably don't need to
 know about them.
 
+=head2 $mech->_update_page($request, $response)
+
+Updates all internal variables in $mech as if $request was just
+performed, and returns $response. The page stack is B<not> altered by
+this method, it is up to caller (e.g. L</request>) to do that.
+
+=cut
+
+sub _update_page {
+    my ($self, $request, $res) = @_;
+
+    $self->{req} = $request;
+    $self->{redirected_uri} = $request->uri->as_string;
+
+    $self->{res} = $res;
+
+    # These internal hash elements should be dropped in favor of
+    # the accessors soon. -- 1/19/03
+    $self->{status}  = $res->code;
+    $self->{base}    = $res->base;
+    $self->{ct}      = $res->content_type || "";
+
+    if ( $res->is_success ) {
+        $self->{uri} = $self->{redirected_uri};
+        $self->{last_uri} = $self->{uri};
+    } else {
+        if ( $self->{autocheck} ) {
+            $self->die( "Error ", $request->method, "ing ", $request->uri, ": ", $res->message );
+        }
+    }
+
+    $self->_reset_page;
+    if ($self->is_html) {
+        $self->update_html($res->content);
+    } else {
+        $self->{content} = $res->content;
+    }
+
+    return $res;
+} # _update_page
+
+
+=head2 $mech->_modify_request( $req )
+
+Modifies the request according to all the internal header mangling.
+
+=cut
+
+sub _modify_request {
+    my $self = shift;
+    my $req = shift;
+
+    # add correct Accept-Encoding header to restore compliance with
+    # http://www.freesoft.org/CIE/RFC/2068/158.htm
+    unless ( $req->header( 'Accept-Encoding' ) ) {
+        # Only allow "identity" for the time being
+        $req->header( 'Accept-Encoding', 'identity' );
+    }
+
+    my $last = $self->{last_uri};
+    if ( $last ) {
+        $last = $last->as_string if ref($last);
+        $req->header( Referer => $last );
+    }
+    while ( my($key,$value) = each %{$self->{headers}} ) {
+        if ( defined $value ) {
+            $req->header( $key => $value );
+        } else {
+            $req->remove_header( $key );
+        }
+    }
+
+    return $req;
+}
+
+
+=head2 $mech->_make_request()
+
+Convenience method to make it easier for subclasses like
+L<WWW::Mechanize::Cached> to intercept the request.
+
+=cut
+
+sub _make_request {
+    my $self = shift;
+    $self->SUPER::request(@_);
+}
+
 =head2 $mech->_reset_page()
 
 Resets the internal fields that track page parsed stuff.
@@ -1738,7 +1878,7 @@ sub _reset_page {
     return;
 }
 
-=head2 $mech->_extract_links_and_images()
+=head2 $mech->_extract_links()
 
 Extracts links from the content of a webpage, and populates the C<{links}>
 property with L<WWW::Mechanize::Link> objects.
@@ -1753,28 +1893,37 @@ my %link_tags = (
     meta => "content",
 );
 
-my %image_tags = (
-    img => "src",
-    input => "src",
-);
-
-sub _extract_links_and_images {
+sub _extract_links {
     my $self = shift;
 
     my $parser = HTML::TokeParser->new(\$self->{content});
 
     $self->{links} = [];
+
+    while ( my $token = $parser->get_tag( keys %link_tags ) ) {
+        my $link = $self->_link_from_token( $token, $parser );
+        push( @{$self->{links}}, $link ) if $link;
+    } # while
+
+    return;
+}
+
+
+my %image_tags = (
+    img => "src",
+    input => "src",
+);
+
+sub _extract_images {
+    my $self = shift;
+
+    my $parser = HTML::TokeParser->new(\$self->{content});
+
     $self->{images} = [];
 
-    while (my $token = $parser->get_tag( keys %link_tags, keys %image_tags )) {
-        my $tag = $token->[0];
-        if ( $link_tags{ $tag } ) {
-            my $link = $self->_link_from_token( $token, $parser );
-            push( @{$self->{links}}, $link ) if $link;
-        } else {
-            my $image = $self->_image_from_token( $token, $parser );
-            push( @{$self->{images}}, $image ) if $image;
-        }
+    while ( my $token = $parser->get_tag( keys %image_tags ) ) {
+        my $image = $self->_image_from_token( $token, $parser );
+        push( @{$self->{images}}, $image ) if $image;
     } # while
 
     return;
@@ -1790,7 +1939,7 @@ sub _image_from_token {
 
     if ( $tag eq "input" ) {
         my $type = $attrs->{type} or return;
-        return unless $type eq "submit";
+        return unless $type eq "image";
     }
 
     require WWW::Mechanize::Image;
@@ -1875,10 +2024,6 @@ object.
 sub _push_page_stack {
     my $self = shift;
 
-    # Hook for reload() and maybe future code (e.g. 302 chasing,
-    # frames) that may want to fetch stuff without altering the history.
-    return 1 if $self->{inhibit_page_stack};
-
     # Don't push anything if it's a virgin object
     if ( $self->{res} ) {
         my $save_stack = $self->{page_stack};
@@ -1903,10 +2048,6 @@ sub _push_page_stack {
 sub _pop_page_stack {
     my $self = shift;
 
-    # Hook for reload() and maybe future code (e.g. 302 chasing,
-    # frames) that may want to fetch stuff without altering the history.
-    return 1 if $self->{inhibit_page_stack};
-
     if (@{$self->{page_stack}}) {
         my $popped = pop @{$self->{page_stack}};
 
@@ -1945,7 +2086,7 @@ sub warn {
 =head2 die( @messages )
 
 Centralized error method.  Defaults to calling C<CORE::die>, but
-may be overridden by setting C<onerror> in the construcotr.
+may be overridden by setting C<onerror> in the constructor.
 
 =cut
 
@@ -1970,6 +2111,14 @@ sub _die {
     &Carp::croak; # pass thru
 }
 
+__END__
+
+=head1 WWW::MECHANIZE'S SUBVERSION REPOSITORY
+
+Mech is hosted by the kind generosity of Ask and Robert,
+maintainers of perl.org.  The Subversion repository is at
+L<http://svn.perl.org/modules/www-mechanize>.
+
 =head1 OTHER DOCUMENTATION
 
 =head2 I<Spidering Hacks>, by Kevin Hemenway and Tara Calishain
@@ -1999,7 +2148,7 @@ There are six hacks that use Mech or a Mech derivative:
 The book was also positively reviewed on Slashdot:
 L<http://books.slashdot.org/article.pl?sid=03/12/11/2126256>
 
-=head2 Online resources
+=head1 ONLINE RESOURCES
 
 =over 4
 
@@ -2021,6 +2170,29 @@ for Mech.
 A random array of examples submitted by users, included with the
 Mechanize distribution.
 
+=back
+
+=head1 ARTICLES ABOUT WWW::MECHANIZE
+
+=over 4
+
+=item * L<http://www.oreilly.com/catalog/googlehks2/chapter/hack84.pdf>
+
+Leland Johnson's hack #84 in I<Google Hacks, 2nd Edition> is
+an example of a production script that uses WWW::Mechanize and
+HTML::TableContentParser. It takes in keywords and returns the estimated
+price of these keywords on Google's AdWords program.
+
+=item * L<http://www.perl.com/pub/a/2004/06/04/recorder.html>
+
+Linda Julien writes about using HTTP::Recorder to create WWW::Mechanize
+scripts.
+
+=item * L<http://www.developer.com/lang/other/article.php/3454041>
+
+Jason Gilmore's article on using WWW::Mechanize for scraping sales
+information from Amazon and eBay.
+
 =item * L<http://www.perl.com/pub/a/2003/01/22/mechanize.html>
 
 Chris Ball's article about using WWW::Mechanize for scraping TV
@@ -2052,6 +2224,14 @@ Here are modules that use or subclass Mechanize.  Let me know of any others:
 
 =item * L<Finance::Bank::LloydsTSB>
 
+=item * L<HTTP::Recorder>
+
+Acts as a proxy for web interaction, and then generates WWW::Mechanize scripts.
+
+=item * L<Win32::IE::Mechanize>
+
+Just like Mech, but using Microsoft Internet Explorer to do the work.
+
 =item * L<WWW::Bugzilla>
 
 =item * L<WWW::Google::Groups>
@@ -2115,11 +2295,15 @@ Jan Pazdziora,
 Dominique Quatravaux,
 Scott Lanning,
 Rob Casey,
+Leland Johnson,
+Joshua Gatcomb,
+Julien Beasley,
+Abe Timmerman,
 and the late great Iain Truskett.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 Andy Lester. All rights reserved. This program is
+Copyright (c) 2005 Andy Lester. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
